Monty Python's Flying Circus: Just the Words - Episode 5

# Episode Five: Man's crisis of identity in the latter half of the twentieth century

Confuse-a-Cat
The smuggler
A duck, a cat and a lizard (discussion)
Vox pops on smuggling
Police raid
Letters and vox pops
Newsreader arrested
Erotic film
Silly job interview
Careers advisory board
Burglar/encyclopedia salesman

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A river. The 'It's' man rows towards the camera and announces:
It's Man | It's...
Voice Over | (and CAPTION:) 'MONTY PYTHON'S FLYING CIRCUS'
| Title animation. SUPERIMPOSED CAPTION: 'SUBURBAN LOUNGE NEAR ESHER' Elderly couple, Mr A and Mrs B are staring through french windows at a cat that is sitting in the middle of their lawn motionless and facing away from them. A car is heard drawing up.
Mr A | Oh good, that'll be the Vet, dear.
Mrs B | I'd better go and let him in.
| Mrs B goes out and comes back into the room with the Vet.
Mrs B | (stage whisper) It's the Vet, dear.
Mr A | Oh very glad indeed you could come round, sir.
Vet | Not at all. Now what seems to be the problem? You can tell me - I'm a Vet, you know.
Mrs B | See! Tell him, dear.
Mr A | Well...
Mrs B | It's our cat. He doesn't do anything. He just sits out there on the lawn.
Vet | Is he ... dead?
Mr A | Oh, no!
Vet | (to camera dramaticaly) Thank God for that. For one ghastly moment I thought I was... too late. If only more people would call in the nick of time.
Mrs B | He just sits there, all day and every day.
Mr A | And at night.
Mrs B | Sh! Almost motionless. We have to take his food out to him.
Mr A | And his milk.
Mrs B | Sh! He doesn't do anything. He just sits there.
Vet | Are you at your wits' end?
Mrs B | Definitely, yes.
Vet | Hm. I see. Well I think I may be able to help you. You see ... (he goes over to armchair, puts on spectacles, sits, crosses legs and puts finger tips together)... your cat is suffering from what we Vets haven't found a word for. His condition is typified by total physical inertia, absence of interest in its ambience - what we Vets call environment - failure to respond to the conventional external stimuli - a ball of string, a nice juicy mouse, a bird. To be blunt, your cat is in a rut. It's the old stockbroker syndrome, the suburban fin de siecle ennui, angst, weltschmertz, call it what you will.
Mrs B | Moping.
Vet | In a way, in a way ... hum ... moping, I must remember that. Now, what's to be done? Tell me sir, have you confused your cat recently?
Mr A | Well we ...
Mrs B | Sh! No.
Vet | Yes ... well I think I can definitely say that your cat badly needs to be confused.
Mrs B | What?
Mr A | Sh! What?
Vet | Confused. To shake it out of its state of complacency. I'm afraid I'm not personally qualified to confuse cats, but I can recommend an extremely good service. Here is their card.
Mrs B | (reading card) Oooh. 'Confuse-a-Cat Limited'.
Mr A | 'Confuse-a-Cat Limited'.'
Mrs B | Oh.
| Cut to large van arriving. On one side is a large sign readling 'Confuse-a-Cat Limited: Europe's leading cat-confusing service. By appointment to...' and a crest. Several people get out of the van, dressed in white coats, with peaked caps and insignia. One of them has a sergeant's stripes.
Sergeant | Squad! Eyes front! Stand at ease. Cat confusers ...shun!
| From a following car a general alights.
General | Well men, we've got a pretty difficult cat to confuse today so let's get straight on with it. Jolly good. Thank you sergeant.
Sergeant | Confusers attend to the van and fetch out... wait for it... fetch out the funny things. (the men unload the van) Move, move, move. One, two, one, two, get those funny things off.
| The workmen are completing the erection of a proscenium with curtains in front of the still immobile cat. A and B watch with awe. The arrangements are completed. All stand ready.
Sergeant | Stage ready for confusing, sir!
General | Very good. Carry on, sergeant.
Sergeant | Left turn, double march!
General | Right men, confuse the ... cat!
| Drum roll and cymbals. The curtains draw back and an amazing show takes place, using various tricks: locked camera, fast motion, jerky motion, jump cuts, some pixilated motion etc. Long John Silver walks to front of stage.
Long John Silver | My lords, ladies and Gedderbong.
| Long John Silver disappears. A pause. Two boxers appear. They circle each other. On one's head a bowler hat appears, vanishes. On the other's a sterve-pipe hat appears. On the first's head is a fez. The stove-pipe hat becomes a stetson. The fez becomes a cardinal's hat. The stetson becomes a wimple. Then the cardinal's hat and the wimple vanish. One of the boxers becomes Napoleon and the other boxer is astonished. Napoleon punches the boxer with the hand inside his jacket. The boxer falls, stunned. Horizontally he shoots off stage. Shot of cat, watching unimpressed. Napoleon does one-legged pixilated dance across stage and off, immediately reappearinng on other side of stage doing same dance in same direction. He reaches the other side, but is halted by a traffic policeman. The policeman beckons onto the stage a man in a penguin skin on a pogostick. The penguin gets halfway across and then turns into a dustbin. Napoleon hops off stage. Policeman goes to dustbin, opens it and Napoleon gets out. Shot of cat, still unmoved. A nude man with a towel round his waist gets out of the dustbin. Napoleon points at ground. A chair appears where he points. The nude man gets on to the chair, jumps in the air and vanishes. Then Napoleon points to ground by him and a small cannon appears. Napoleon fires cannon and the policeman disappears. The man with the towel round his waist gets out of the dustbin and is chased off stage by the penguin on the pogostick. A sedan chair is carried on stage by two chefs. The man with the towel gets out and the penguin appears from the dustbin and chases him off. Napoleon points to sedan chair and it changes into dustbin. Man in towel runs back on to stage and jumps in dustbin. He looks out and the penguin appears from the other dustbin and hits him on the head with a raw chicken. Shot of cat still unimpressed. Napoleon, the man with the towel round his waist, the policeman, a boxer, and a chef suddenly appear standing in a line, and take a bow. They immediately change positions and take another bow. The penguin appears at the end of the line with a puff of smoke. Each one in turn jumps in the air and vanishes. Shot of passive cat. Cut to Mr A and Mrs B watching with the general.
General | I hope to God it works. Anyway, we shall know any minute now.
| After a pause, the cat gets up and walks into the house. Mr A and Mrs B are overcome with joy.
Mrs B | I can't believe it.
Mr A | Neither can I. It's just like the old days.
Mrs B | Then he's cured. Oh thank you, general.
Mr A | What can we ever do to repay you?
General | No need to, sir. It's all in a day's work for 'Confuse-a-Cat'.
| Picture freezes and over still of general's face are superimposed the words 'Confuse-a-Cat Limited'. Dramatic music. The words start to roll, like ordinary credits but read: CONFUSE-A-CAT LIMITED INCORPORATING AMAZE-A-VOLE LTD STUN-A-STOAT LTD PUZZLE-A-PUMA LTD STARTLE-A-THOMPSON'S GAZELLE LTD BEWILDEREBEEST INC DISTRACT-A-BEE
| ANIMATION: People's heads appear in frame due to Mr Gilliam's animation on film. Film animation leads us into customs hall.
Officer | Have you read this, sir? (holds up notice)
Man | No! Oh, yes, yes - yes.
Officer | Anything to declare?
Man | Yes ... no! No! No! No! Nothing to declare, no, nothing in my suitcase no...
Officer | No watches, cameras, radio sets?
Man | Oh yes ... four watches ... no, no, no. No. One... one watch...No, no. Not even one watch. No, no watches at all. No, no watches at all. No precision watches, no.
Officer | Which country have you been visiting, sir?
Man | Switzerland ... er ... no ... no ... not Switzerland ... er ... not Switzerland, it began with S but it wasn't Switzerland... oh what could it be? Terribly bad memory for names. What's the name of that country where they don't make watches at all?
Officer | Spain?
Man | Spain! That's it. Spain, yes, mm.
Officer | The label says 'Zurich', sir.
Man | Yes well ... it was Spain then.
Officer | Zurich's in Switzerland, sir.
Man | Switzerland, yes mm ... mm ... yes.
Officer | Switzerland - where they make the watches.
Man | Oh, nice shed you've got here.
Officer | Have you, er, got any Swiss currency, sir?
Man | No... just the watches... er just my watch, er, my watch on the currency... I've kept a watch on the currency, and I've watched it and I haven't got any.
Officer | That came out a bit glib didn't it? (an alarm clock goes off inside his case; the Man thumps it, unsuccessfully) Have you got an alarm clock in there, sir?
Man | No, no, heavens no, no... just vests. (he thumps the case and the alarm stops)
Officer | Sounded a bit like an alarm going off.
Man | Well it can't have been... it must be a vest, er, going off.
Officer | Going off?
| Clocks start ticking and chiming in the case. The man desperately thumps the case.
Man | All right, I confess, I'm a smuggler ... This whole case is crammed full of Swiss watches and clocks. I've been purposely trying to deceive Her Majesty's Customs and Excise. I've been a bloody fool.
Officer | I don't believe you, sir.
Man | It's true. I'm, er, guilty of smuggling.
Officer | Don't give me that, sir ... you couldn't smuggle a piece of greaseproof paper let alone a case full of watches.
Man | What do you mean! I've smuggled watches before, you know! I've smuggled bombs, cameras, microfilms, aircraft components, you name it - I've smuggled it.
Officer | Now come along please, you're wasting our time... move along please.
Man | Look! (he opens his case to reveal it stuffed full of watches and clocks) Look - look at this.
Officer | Look, for all I know, sir, you could've bought these in London before you ever went to Switzerland.
Man | What? I wouldn't buy two thousand clocks.
Officer | People do, now close your case move along please come on. Don't waste our time, we're out to catch the real smugglers. Come on.
Man | (shouting) I am a real smuggler. I'm a smuggler! Don't you understand, I'm a smuggler, a lawbreaker... a smuggler. (he is removed struggling)
| A vicar is next.
Vicar | Poor fellow. I think he needs help.
Officer | Right, cut the wisecracks, vicar. Get to the search room, and strip.
| Cut to chairman of discussion group.
Chairman | Well to discuss the implications of that sketch and to consider the moral problems raised by the law-enforcement methods involved we have a duck, a cat and a lizard. Now first of all I'd like to put this question to you please, lizard. How effective do you consider the legal weapons employed by legal customs officers, nowadays? (shot of lizard; silence) Well while you're thinking about that, I'd like to bring the duck in here, and ask her, if possible, to clarify the whole question of currency restrictions, and customs regulations in the world today. (shot of duck; silence) Perhaps the cat would rather answer that? (shot of cat; silence) No? Lizard? (shot of lizard again and then back) No. Well, er, let's ask the man in the street what he thinks.
| Cut to film: vox pops.
French Au Pair | I am not a man you silly billy.
Man on Roof | I'm not in the street you fairy.
Man in Street | Well, er, speaking as a man in the street... (a car runs him over) Wagh!
Man | What was the question again?
Voice Over | Just how relevant are contemporary customs regulations and currency restrictions in a modern expanding industrial economy? (no answer) Oh never mind.
Pepperpot | Well I think customs men should be armed, so they can kill people carrying more than two hundred cigarettes.
Man | (getting up from a deckchair and screaming with indignation and rage: he has a knotted handkerchief on his head and his trousers are rolled up to the knees) Well I, I think that, er, nobody who has gone abroad should be allowed back in the country. I mean, er, blimey, blimey if they're not keen enough to stay here when they're 'ere, why should we allow them back, er, at the tax-payers' expense? I mean, be fair, I mean, I don't eat squirrels do I? I mean well perhaps I do one or two but there's no law against that, is there? It's a free country. (enter a knight in amour) I mean if I want to eat a squirrel now and again, that's me own business, innit? I mean, I'm no racialist. I, oh, oh...
| The knight is carrying a raw chicken. The man apprehensively covers his head and the knight slams him in the stomach with the chicken.
Woman | I think it's silly to ask a lizard what it thinks, anyway.
Chairman | (off) Why?
Woman | I mean they should have asked Margaret Drabble.
Young Man | (very reasonably) Well I think, er, customs people are quite necessary, and I think they're doing quite a good job really. Check.
| We now see that he is playing chess with another young man. They are in an ordinary flat. There is a tremendous battering, banging, hammering and clattering at the door.
Young Man | Door's open.
Policeman | Oh. Yes. (he enters) All right. All right, all right, all right. My name's Police Constable Henry Thatcher, and this is a raid. I have reason to believe that there are certain substances on the premises.
Young Man | Well what sort of substances, officer?
Policeman | Er... certain substances.
Young Man | Well, what sort of certain substances?
Policeman | Er, certain substances of an illicit nature.
Young Man | Er, could you be more specific?
Policeman | I beg your pardon?
Young Man | Could you be 'clearer'.
Policeman | Oh, oh ... yes, er ... certain substances on the premises. To be removed for clinical tests.
Young Man | Have you got anything patiticular in mind?
Policeman | Well what have you got?
Young Man | Nothing, officer.
Policeman | You are Sandy Camp the actor?
Young Man | Yes.
Policeman | I must warn you, sir, that outside I have police dog Josephine, who is not only armed, and trained to sniff out certain substances, but is also a junkie.
Young Man | What are you after ... ?
Policeman | (pulling a brown paper package from out of his pocket, very badly and obviously) Oo! Oh, oh, oh, oh, oh, oh, oh, oh, oh, oh! Here is a brown paper bag I have found on the premises. I must confiscate this, sir, and take it with me for clinical examination.
Young Man | Wait a minute. You just got that out of your pocket.
Policeman | What?
Young Man | (takes it) Well what's in it anyway? (opens it) Sandwiches.
Policeman | Sandwiches? Blimey. Whatever did I give the wife?
| Cut to viewer's letter in handwriting, read in voice over.
Voice Over | Dear BBC, East Grinstead, Friday. I feel I really must write and protest about that sketch. My husband, in common with a lot of people of his age, is fifty. For how long are we to put up with these things. Yours sincerely, E. B. Debenham (Mrs).
| Cut to another letter.
Voice Over | Dear Freddy Grisewood, Bagshot, Surrey. As a prolific letter-writer, I feel I must protest about the previous letter. I am nearly sixty and am quite mad, but I do enjoy listening to the BBC Home Service. If this continues to go on unabated ...Dunkirk... dark days of the war... backs to the wall... Alvar Liddell ... Berlin air lift ... moral upheaval of Profumo case ... young hippies roaming the streets, raping, looting and killing. Yours etc., Brigadier Arthur Gormanstrop (Mrs).
| Cut to vox pops film.
Pepperpot | Well I think they should attack things, like that - with satire. I mean Ned Sherrin. Fair's fair. I think people should be able to make up their own minds for me.
Woman Journalist | Well I think they should attack the fuddy-duddy attitudes of the lower middle classes which permit the establishment to survive and keep the mores of the whole country back where they were in the nineteenth century and the ghastly days of the pre-sexual revolution.
| A boxer (Eric) runs up and knocks her out.
Scotsman | Well that's, er, very interesting, because, er, I am, in fact, made entirely of wood.
Stockbroker | Well I think they should attack the lower classes, er, first with bombs, and rockets destroying their homes, and then when they run helpless into the streets, er, mowing them down with machine guns. Er, and then of course releasing the vultures. I know these views aren't popular, but I have never courted popularity.
| A boy scout on his knees. Next to him is a scout master, seen only from the knees down.
Boy | I think there should be more race prejudice.
| He is nudged.
Voice | Less.
Boy | Less race prejudice.
| Cut to news studio with a large screen behind newsreader.
Newsreader | (as if it's the fourth item)) ... and several butchers aprons. In Fulham this morning a jeweller's shop was broken into and jewellery to the value of £2,000 stolen. Police have issued this picture of a man they wish to interview. (on the screen behind, him, there appears an identical picture of him, sitting at his newsreader desk) The man is in his late twenties wearing a grey suit, a white shirt and a floral tie. (on the screen behind, police come in and remove the newsreader) Will anyone who sees this man or can give any information about his whereabouts contact their nearest policestation. (he is handed a piece of paper) Ah! Oh. We've just heard that police have detained the man they wished to interview in connection with the jewel robbery. Ah, but after questioning police have ruled him out of their enquiries and released him. (the other newsreader appears back on the screen and sits down) Sport. (he is handed another piece of paper) Ah, they say, however, that acting on his information they now wish to interview a newsreader in the central London area. Ah, police are concentrating their enquiries on the British Broadcasting Corp ... (a policeman comes in, and removes newsreader in the foreground) Excuse me a minute...
| The newsreader on the screen behind continues.
Other Newsreader | We understand a man is now helping police with their enquiries. And that is the end of the news. (he clips a piece of jewellery on to his ear) And now, 'Match of the Day'.
| 'Match of the Day' music. We see a couple. They are standing at the foot of a largish bed. She is in bra and pants. He is in Y-fronts. They kiss ecstaticaly. After a few seconds there is the sound of a car drawing up. The crunch of footsteps on gravel and the sound of a door opening. The newsreader comes into shot.
Newsreader | Ah, I, Um terribly sorry it's not in fact 'Match of the Day'-, it is in fact edited highlights of tonight's romantic movie. Er. Sorry. (he goes out of shot; the two clinch again; after a second he pops back into shot) Ooh, I'm sorry, on BBC2 Joan Bakewell will be talking to Michael Dean about what makes exciting television. (pops out of shot, then pops in again) Ah, sorry about all that. And now back to the movie. (he goes)
| The couple continue to neck.
She | Oh, oh, oh Bevis, should we?
Bevis | Oh Dora. Why not?
She | Be gentle with me.
| Cut to film montage. Collapsing factory chimney in reverse motion; pan up tall soaring poplars in the wind; waves crashing; fish in shallow water fountains; exploding fireworks; volcano erupting with lava; rocket taking off, express train going into a tunnel; dam bursting; battleship broadside; lion leaping through flaming hoop; Richard Nixon smiling; milking a cow; planes refuelling in mid-air; Women's Institute applauding; tossing the caber; plane falling in flames; tree crashing to the ground; the lead shot tower collapsing (normal motion). Cut back to the girl in bed.
She | (smoking) Oh Bevis, are you going to do anything or are you just going to show me films all evening?
| We see Bevis, with small projector.
Bevis | Just one more, dear.
She | Oh.
| He starts it. A two-minute extravaganza constructed by Mr Terry Gilliam of America you know. Cut to an interview room.
Interviewer | You know I really enjoy interviewing applicants for this management training course. (knock at door) Come in. (Stig enters) Ah. Come and sit down.
Stig | Thank you. (he sits)
Interviewer | (stares at him and starts writing) Would you mind just standing up again for one moment. (stands up) Take a seat.
Stig | I'm sorry.
Interviewer | Take a seat. (Stig does so) Ah! (writes again) Good morning.
Stig | Good morning.
Interviewer | Good morning.
Stig | Good morning.
Interviewer | (writes) Tell me why did you say 'good morning' when you know perfectly well that it's afternoon?
Stig | Well, well, you said 'good morning'. Ha, ha.
Interviewer | (shakes head) Good afternoon.
Stig | Ah, good afternoon.
Interviewer | Oh dear. (writes again) Good evening.
Stig | ... Goodbye?
Interviewer | Ha, ha. No. (rings small hand-bell) ... Aren't you going to ask me why I rang the bell? (rings bell again)
Stig | Er why did you ring the bell?
Interviewer | Why do you think I rang the bell? (shouts) Five, four, three, two, one, zero!
Stig | Well, I, I...
Interviewer | Too late! (singing) Goodnight, ding-ding-ding-ding-ding. Goodnight. Ding-ding-ding-ding-ding-ding-ding.
Stig | Um. Oh this is, is the interview for the management training course is it?
Interviewer | (Rings bell) Yes. Yes it is. Goodnight. Ding, ding, ding, ding, ding, ding, ding, ding.
Stig | Oh. Oh dear, I don't think I'm doing very well.
Interviewer | Why do you say that?
Stig | Well I don't know.
Interviewer | Do you say it because you didn't know?
Stig | Well. I, I, I, I don't know.
Interviewer | Five, four, three, two, one, zero! Right! (makes face and strange noise)
Stig | I'm sorry, I'm confused.
Interviewer | Well why do you think I did that then?
Stig | Well I don't know.
Interviewer | Aren't you curious?
Stig | Well yes.
Interviewer | Well, why didn't you ask me?
Stig | Well...I...er...
Interviewer | Name?
Stig | What?
Interviewer | Your name man, your name!
Stig | Um, er David.
Interviewer | David. Sure?
Stig | Oh yes.
Interviewer | (writing) David Shaw.
Stig | No, no Thomas.
Interviewer | Thomas Shaw?
Stig | No, no, David Thomas.
Interviewer | (long look, rings bell) Goodnight. Ding-ding-ding-ding-ding- ding-ding-ding. Goodnight. Ding-ding-ding-ding-ding-ding-ding-ding-ding.
Stig | Oh dear we're back to that again. I don't know what to do when you do that.
Interviewer | Well do something. Goodnight. Ding-ding-ding-ding-ding, five, four, three, two, one . . .(Stig pulls face and makes noise) Good!
Stig | Good?
Interviewer | Very good - do it again. (Stig pulls face and makes noise) Very good indeed, quite outstanding. (Interviewer goes to door) Ah right. (calls through door) Ready now. (four people come in and line up by desk) Right, once more. (rings bell) Goodnight, ding-ding-ding-ding-ding-ding.
| Stig very cautiously pulls face and makes noise. Interviewer rings bell again. Suddenly the four men all hold up points cards like diving or skating judges.
Stig | What's going on? What's going on?
Interviewer | You've got very good marks.
Stig | (hysterically) Well I don't care, I want to know what's going on! I think you're deliberately trying to humiliate people, and I'm going straight out of here and I'm going to tell the police exactly what you do to people and I'm going to make bloody sure that you never do it again. There, what do you think of that? What do you think of that?
| The judges give him very high marks.
Interviewer | Very good marks.
Stig | Oh, oh well, do I get the job?
Interviewer | Er, well, I'm afraid not. I'm afraid all the vacancies were filled several weeks ago.
| They fall about laughing. Cut to man sitting at desk.
Man | Well that was all good fun, and we all had a jolly good laugh, but I would like to assure you that you'd never be treated like that if you had an interview here at the Careers Advisory Board. Perhaps I should introduce myself. I am the Head of the Careers Advisory Board. I wanted to be a doctor, but there we are, I'm Head of the Careers Advisory Board. (emotionally) Or a sculptor, something artistic, or an engineer, with all those dams, but there we are, it's no use crying over split milk, the facts are there and that's that. I'm the Head of this lousy Board. (he weeps, then recovers) Never mind, now I wonder if you've ever considered what a very profitable line of work this man is in.
| Cut to front door of a flat. Man walks up to the door and rings bell. He is dressed smartly.
Man | Burglar! (longish pause while he waits, he rings again) Burglar! (woman appears at other side of door)
Woman | Yes?
Man | Burglar, madam.
Woman | What do you want?
Man | I want to come in and steal a few things, madam.
Woman | Are you an encydopaedia salesman?
Man | No madam, I'm a burglar, I burgle people.
Woman | I think you're an encyclopaedia salesman.
Man | Oh I'm not, open the door, let me in please.
Woman | If I let you in you'll sell me encyclopaedias.
Man | I won't, madam. I just want to come in and ransack the flat. Honestly.
Woman | Promise. No encyclopaedias?
Man | None at all.
Woman | All right. (she opens door) You'd better come in then.
| Man enters it through door.
Man | Mind you I don't know whether you've really considered the advantages of owning a really fine set of modern encyclopaedias...(he pockets valuable) You know, they can really do you wonders.
| Cut back to man at desk.
Man | That man was a successful encyclopaedia salesman. But not all encyclopaedia salesmen are successful. Here is an unsuccessful encyclopaedia salesman.
| Cut to very tall building; a body flies out of a high window and plummets. Cut back to man at desk.
Man | Now here are two unsuccessful encyclopaedia salesmen.
| Cut to a different tall building; two bodies fly out of a high window. Cut back to man at desk.
Man | I think there's a lesson there for all of us.
| CAPTION: '"MAN'S CRISIS OF IDENTITY IN THE LATTER HALF OF THE 20TH CENTURY" WAS CONCIEVED, WRITTEN AND PERFORMED BY... (CREDITS)'